import 'package:cargocalculaterapp/features/home/data/models/comment_request.dart';
import 'package:cargocalculaterapp/features/home/data/models/comment_response.dart';
import 'package:cargocalculaterapp/features/home/data/models/notification_response.dart';
import 'package:cargocalculaterapp/features/home/data/models/order_single_response.dart';
import 'package:cargocalculaterapp/features/home/data/models/orders_list_response.dart';
import 'package:cargocalculaterapp/features/home/data/models/read_notification_request.dart';
import 'package:cargocalculaterapp/features/home/data/models/read_notification_response.dart';

import '../../models/banner_response.dart';

abstract class HomeRemoteDataSource {
  Future<OrdersListResponse> ordersList(Map<String, dynamic> request);

  Future<OrderSingleResponse> orderSingle(String orderId);

  Future<CommentResponse> comment(CommentRequest request);

  Future<NotificationResponse> notification(Map<String, dynamic> request);

  Future<ReadNotificationResponse> notificationRead(
    ReadNotificationRequest request,
  );

  Future<List<BannerResponse>> bannersResponse();
}
